@@ -35,7 +35,7 @@ Saiyam Kohli,                University of Minnesota Duluth
 
 =head1 HISTORY
 
-Last updated: $Id: statistic.pl,v 1.27 2011/12/23 22:25:04 btmcinnes Exp $
+Last updated: $Id: statistic.pl,v 1.28 2015/10/03 12:22:33 tpederse Exp $
 
 =head1 BUGS
 
@@ -726,8 +726,10 @@ while(<SRC>)
     chomp $_;
 
     # get the various fields of the record!
-    if ( defined @tokens  ) { undef @tokens;  }
-    if ( defined @numbers ) { undef @numbers; }
+
+## removed by tdp oct 3, 2015 due to perl deprecation of defined @array
+##    if ( defined @tokens  ) { undef @tokens;  }
+##    if ( defined @numbers ) { undef @numbers; }
 
     # ADP.67.1
     # in old versions, ngramString variable was storing only the
