@@ -412,14 +412,14 @@ Amruta Purandare,            University of Pittsburgh
                              E<lt>amruta@cs.pitt.eduE<gt>
 
 Bridget Thomson-McInnes,     University of Minnesota Twin Cities
-                             E<lt>bthompson@d.umn.eduE<gt>
+                             E<lt>bthomson@d.umn.eduE<gt>
 
 Saiyam Kohli,                University of Minnesota Duluth
                              E<lt>kohli003@d.umn.eduE<gt>
 
 =head1 HISTORY
 
-Last updated: $Id: MI.pm,v 1.2 2010/11/12 18:40:23 btmcinnes Exp $
+Last updated: $Id: MI.pm,v 1.3 2011/12/23 22:25:05 btmcinnes Exp $
 
 =head1 BUGS
 
@@ -433,7 +433,7 @@ L<http://www.d.umn.edu/~tpederse/nsp.html>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000-2006, Ted Pedersen, Satanjeev Banerjee, Amruta
+Copyright (C) 2000-2011, Ted Pedersen, Satanjeev Banerjee, Amruta
 Purandare, Bridget Thomson-McInnes and Saiyam Kohli
 
 This program is free software; you can redistribute it and/or modify it
